Provides tools and pre-trained Machine Learning [ML] models for calibration of Agent-Based Models [ABMs] built with the R package 'epiworldR'. Implements methods described in Najafzadehkhoei, Vega Yon, Modenesi, and Meyer (2025) tools:::Rd_expr_doi("10.48550/arXiv.2509.07013"). Users can automatically calibrate ABMs in seconds with pre-trained ML models, effectively focusing on simulation rather than calibration. Bridges a gap by allowing public health practitioners to run their own ABMs without the advanced technical expertise often required by calibration.
Maintainer: Sima Najafzadehkhoei sima.njf@utah.edu (ORCID)
Authors:
George Vega Yon g.vegayon@gmail.com (ORCID)
Jake Wagoner jakew@sci.utah.edu
Bernardo Modenesi bmodenesi@gmail.com
Other contributors:
Centers for Disease Control and Prevention (Award number 1U01CK000585; 75D30121F00003) [funder]